import React, { useEffect, useRef } from 'react';
import styles from './styles';
import { Pressable, Text, View } from 'react-native';
import useDateTimePicker from '../../Hooks/useDateTimePicker';
import {getDateUTCString} from "../../Utilities";
const today = new Date();
export default function Day({ value, label, selected, onPressDay }) {
    const { theme, persianNumber } = useDateTimePicker();
    const isSelected = useRef(selected);
    const labelRef = useRef(null);
    useEffect(() => {
        isSelected.current = selected;
    }, [selected]);
    const selectedDayTextStyle = { color: theme.SelectedDayText };
    return (React.createElement(View, { style: styles.day_container },
        React.createElement(Pressable, { onPressIn: onPressIn, onPressOut: onPressOut, onPress: () => (label ? onPressDay(value) : undefined), android_ripple: label ? { borderless: true, color: theme?.SelectDayRipple } : undefined, style: [
                styles.day,
                ...(selected ? [{ backgroundColor: theme.SelectedDay }] : []),
            ] },
            React.createElement(Text, { ref: labelRef, style: [
                    {
                        color: theme.DayText,
                        fontSize: persianNumber ? 18 : 15,
                    },
                    ...(selected
                        ? [selectedDayTextStyle]
                        : getDateUTCString(value) === getDateUTCString(today)
                            ? [styles.today_text, { color: theme.TodayDayText }]
                            : []),
                ] }, label))));
    function onPressIn() {
        setTimeout(() => {
            if (labelRef.current)
                labelRef.current.setNativeProps({
                    style: [
                        { color: theme.DayText, fontSize: persianNumber ? 18 : 15 },
                        selectedDayTextStyle,
                    ],
                });
        }, 100);
    }
    function onPressOut() {
        if (labelRef.current)
            labelRef.current.setNativeProps({
                style: [
                    { color: theme.DayText, fontSize: persianNumber ? 18 : 15 },
                    ...(isSelected.current
                        ? [selectedDayTextStyle]
                        : getDateUTCString(value) === getDateUTCString(today)
                            ? [styles.today_text, { color: theme.TodayDayText }]
                            : []),
                ],
            });
    }
}
//# sourceMappingURL=index.js.map