import React, { useEffect, useState } from 'react';
import Themes from '../Utilities/Themes';
import Translations from '../Utilities/Translations';
import { convertGregorianToJalali } from '../Utilities';
export var CalendarType;
(function (CalendarType) {
    CalendarType[CalendarType["Gregorian"] = 0] = "Gregorian";
    CalendarType[CalendarType["Jalali"] = 1] = "Jalali";
})(CalendarType || (CalendarType = {}));
export var DateTimePickerMode;
(function (DateTimePickerMode) {
    DateTimePickerMode[DateTimePickerMode["Day"] = 0] = "Day";
    DateTimePickerMode[DateTimePickerMode["Year"] = 1] = "Year";
    DateTimePickerMode[DateTimePickerMode["Hour"] = 2] = "Hour";
    DateTimePickerMode[DateTimePickerMode["Minute"] = 3] = "Minute";
})(DateTimePickerMode || (DateTimePickerMode = {}));
const currentDate = new Date();
export const DateTimePickerContext = React.createContext({
    month: 0,
    year: 2020,
    persianNumber: false,
    theme: Themes.Primary,
    setHour: () => undefined,
    setMode: () => undefined,
    setYear: () => undefined,
    selectedDate: currentDate,
    setMonth: () => undefined,
    setMinute: () => undefined,
    mode: DateTimePickerMode.Day,
    setYearMonth: () => undefined,
    setSelectedDate: () => undefined,
    calendar: CalendarType.Gregorian,
    translation: Translations.DEFAULT,
});
const DateTimePickerProvider = ({ children, persianNumber = false, theme = Themes.Primary, initialDate = currentDate, mode = DateTimePickerMode.Day, calendar = CalendarType.Gregorian, translation = Translations.DEFAULT, }) => {
    const [DateTimePicker, setDateTimePicker] = useState({
        mode: mode,
        theme: theme,
        calendar: calendar,
        translation: translation,
        selectedDate: initialDate,
        persianNumber: persianNumber,
        month: initialDate.getMonth(),
        year: initialDate.getFullYear(),
    });
    useEffect(() => {
        let date = calendar === CalendarType.Gregorian || initialDate.getFullYear() < 1900
            ? initialDate
            : convertGregorianToJalali(initialDate);
        setDateTimePicker({
            ...DateTimePicker,
            mode: mode,
            theme: theme,
            calendar: calendar,
            selectedDate: date,
            month: date.getMonth(),
            year: date.getFullYear(),
            translation: translation,
            persianNumber: persianNumber,
        });
    }, [calendar, persianNumber, translation, theme, mode]);
    return (React.createElement(DateTimePickerContext.Provider, { value: {
            mode: DateTimePicker.mode,
            year: DateTimePicker.year,
            month: DateTimePicker.month,
            theme: DateTimePicker.theme,
            calendar: DateTimePicker.calendar,
            translation: DateTimePicker.translation,
            selectedDate: DateTimePicker.selectedDate,
            persianNumber: DateTimePicker.persianNumber,
            setYear: year => {
                DateTimePicker.selectedDate.setFullYear(year);
                setDateTimePicker({
                    ...DateTimePicker,
                    year: year,
                    mode: DateTimePickerMode.Day,
                    selectedDate: DateTimePicker.selectedDate,
                });
            },
            setHour: hour => {
                DateTimePicker.selectedDate.setHours(hour);
                setDateTimePicker({
                    ...DateTimePicker,
                    selectedDate: new Date(DateTimePicker.selectedDate),
                });
            },
            setMinute: minute => {
                DateTimePicker.selectedDate.setMinutes(minute);
                setDateTimePicker({
                    ...DateTimePicker,
                    selectedDate: new Date(DateTimePicker.selectedDate),
                });
            },
            setMode: mode => {
                setDateTimePicker({ ...DateTimePicker, mode: mode });
            },
            setMonth: month => {
                setDateTimePicker({ ...DateTimePicker, month: month });
            },
            setSelectedDate: date => {
                setDateTimePicker({ ...DateTimePicker, selectedDate: date });
            },
            setYearMonth: (year, month) => {
                setDateTimePicker({ ...DateTimePicker, year: year, month: month });
            },
        } }, children));
};
export default DateTimePickerProvider;
//# sourceMappingURL=DateTimePickerProvider.js.map